Put

Trait Put 

pub trait Put<T> {
    // Required method
    fn put(&mut self, value: T);
}
A trait for objects which provide dropping write access to their value.

Required Methods

fn put(&mut self, value: T)

Puts the value the given value, dropping the old value.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a, T: 'a> Put<T> for WriteOnlyRef<'a, T>